@@ -16,6 +16,7 @@
 #include "game_end.h"
 #include "game_event.h"
 #include "game_save.h"
+#include "game_save_moo13.h"
 #include "game_strp.h"
 #include "game_turn.h"
 #include "game_tech.h"
@@ -37,7 +38,6 @@ static bool game_opt_undo_enabled = true;
 static bool game_opt_year_save_enabled = false;
 static bool game_opt_init_save_enabled = true;
 static bool game_opt_next_turn = false;
-static bool game_opt_save_quit = false;
 
 static struct game_end_s game_opt_end = { GAME_END_NONE, 0, 0, 0, 0 };
 static struct game_new_options_s game_opt_new = GAME_NEW_OPTS_DEFAULT;
@@ -465,9 +465,6 @@ const struct cmdline_options_s main_cmdline_options[] = {
     { "-nextturn", 0,
       options_enable_bool_var, (void *)&game_opt_next_turn,
       NULL, "Go directly to next turn (for reproducing bugs)" },
-    { "-savequit", 0,
-      options_enable_bool_var, (void *)&game_opt_save_quit,
-      NULL, "Save and quit (for debugging)" },
     { 0, 0, 0, 0, 0, 0 }
 };
 
@@ -611,8 +608,12 @@ const struct cfg_items_s game_cfg_items[] = {
     CFG_ITEM_BOOL("msg_filter_soilatmos", &game_opt_message_filter[FINISHED_SOILATMOS]),
     CFG_ITEM_BOOL("msg_filter_stargate", &game_opt_message_filter[FINISHED_STARGATE]),
     CFG_ITEM_BOOL("msg_filter_shield", &game_opt_message_filter[FINISHED_SHIELD]),
+    CFG_ITEM_INT("rules_tech_cost_mul", &game_num_tech_costmul, NULL),
+    CFG_ITEM_INT("rules_tech_cost_mul_human", &game_num_tech_costmuld2, NULL),
+    CFG_ITEM_INT("rules_tech_cost_mul_ai", &game_num_tech_costmula2, NULL),
     CFG_ITEM_BOOL("rules_ai_transport_range_fix", &game_num_ai_trans_range_fix),
     CFG_ITEM_BOOL("rules_ai_4th_colony_curse_fix", &game_num_ai_4_colony_curse_fix),
+    CFG_ITEM_BOOL("rules_ai_first_tech_cost_fix", &game_num_ai_first_tech_cost_fix),
     CFG_ITEM_BOOL("rules_doom_stack_fix", &game_num_doom_stack_fix),
     CFG_ITEM_BOOL("rules_bt_no_tohit_acc", &game_num_bt_no_tohit_acc),
     CFG_ITEM_BOOL("rules_bt_oracle_fix", &game_num_bt_oracle_fix),
@@ -816,6 +817,15 @@ int main_do(void)
                     log_fatal_and_die("Game: could not load save %i\n", load_game_i);
                 }
                 break;
+            case MAIN_MENU_ACT_LOAD_GAME_MOO13:
+                {
+                    char fname[12] = "SAVEX.GAM";
+                    fname[4] = load_game_i + '0' + 1;   /* FIXME */
+                    if (game_save_de_moo13(&game, fname) < 0) {
+                        continue;
+                    }
+                }
+                break;
             case MAIN_MENU_ACT_CONTINUE_GAME:
                 main_menu_continue_game:
                 if (game_save_do_load_i(GAME_SAVE_I_CONTINUE, &game)) {
@@ -833,23 +843,19 @@ int main_do(void)
         game_end.type = GAME_END_NONE;
         while ((game_end.type == GAME_END_NONE) || (game_end.type == GAME_END_FINAL_WAR)) {
             for (; ((game_end.type == GAME_END_NONE) || (game_end.type == GAME_END_FINAL_WAR)) && (game.active_player < game.players); ++game.active_player) {
-                if (IS_AI(&game, game.active_player) || (!IS_ALIVE(&game, game.active_player))) {
+                if (!IS_HUMAN(&game, game.active_player) || (!IS_ALIVE(&game, game.active_player))) {
                     continue;
                 }
                 if (game_opt_next_turn) {
                     game_opt_next_turn = false;
                     break;
                 }
-                if (game_opt_save_quit) {
-                    goto turn_act_quit;
-                }
                 switch (ui_game_turn(&game, &load_game_i, game.active_player)) {
                     case UI_TURN_ACT_LOAD_GAME:
                         main_menu_action = MAIN_MENU_ACT_LOAD_GAME;
                         ui_game_end(&game);
                         goto main_menu_load_game;
                     case UI_TURN_ACT_QUIT_GAME:
-                        turn_act_quit:
                         if (game_save_do_save_i(GAME_SAVE_I_CONTINUE, "Continue", &game)) {
                             log_error("Game: could create continue save\n");
                         }
@@ -875,10 +881,6 @@ int main_do(void)
         switch (game_end.type) {
             case GAME_END_QUIT:
                 log_message("Game: quit (ingame)\n");
-                if (game_opt_save_quit) {
-                    game_opt_save_quit = false;
-                    goto done;
-                }
                 break;
             case GAME_END_NONE:
             case GAME_END_FINAL_WAR:
