@@ -331,11 +331,20 @@ static inline bool IS_PLAYER(const struct game_s *g, player_id_t i)
 
 static inline bool IS_HUMAN(const struct game_s *g, player_id_t i)
 {
+    /*
+        In MOO1, instead of IS_HUMAN, the index is checked for equality to zero,
+        which in turn implicitly guarantees that the index is less than g->players.
+        The IS_PLAYER check eliminates the potential for memory corruption.
+    */
     return IS_PLAYER(g, i) && BOOLVEC_IS0(g->is_ai, i);
 }
 
+static inline bool IS_ALIVE(const struct game_s *g, player_id_t i)
+{
+    return (g->evn.home[i] != PLANET_NONE);
+}
+
 #define IS_AI(_g_, _i_) BOOLVEC_IS1((_g_)->is_ai, (_i_))
-#define IS_ALIVE(_g_, _i_) ((_g_)->evn.home[(_i_)] != PLANET_NONE)
 
 extern bool game_opt_skip_intro_always;
 extern bool game_opt_message_filter[FINISHED_NUM];
