@@ -156,8 +156,6 @@ static void audience_build_diplo_msg(struct audience_s *au, bool framed)
                     } else if (eh->trade_bc[pa] != 0) {
                         s = game_str_au_tradea;
                     } else {
-                        /* The placeholder only makes sense if the player and AI
-                         * at least have a trade agreement. */
                         s = game_str_au_treaty;
                     }
                     break;
@@ -724,8 +722,10 @@ static void audience_menu_threat(struct audience_s *au)
         default:
             break;
     }
-    if ((selected != -1) && (selected != 4)) {
+    if ((g->ai_id == GAME_AI_CLASSIC) || ((selected != -1) && (selected != 4))) {
         game_diplo_annoy(g, ph, pa, 10);    /* WASBUG MOO1 does this before the if, annoying by merely entering the menu */
+    }
+    if ((selected != -1) && (selected != 4)) {
         game_audience_set_dtype(au, dtype, 3);
     }
 }
