@@ -120,7 +120,7 @@ static void game_battle_place_items(struct battle_s *bt)
             {
                 const struct battle_item_s *b;
                 b = &(bt->item[0]);
-                if ((b->side != SIDE_NONE) && (b->sx == x) && (b->sy == y)) {
+                if ((b->side != SIDE_NONE) && (abs(b->sx - x) <= 1) && (abs(b->sy - y) <= 1)) {
                     flag_ok = false;
                 }
             }
@@ -417,9 +417,9 @@ static void game_battle_missile_move(struct battle_s *bt, int missile_i, int tar
                 struct battle_rock_s *r = &(bt->rock[i]);
                 if (1
                   && ((r->sx * 32 + 2) <= mx0)
-                  && ((r->sx * 32 + 30) > mx0)
+                  && ((r->sx * 32 + 30) >= mx0)
                   && ((r->sy * 24 + 2) <= my0)
-                  && ((r->sy * 24 + 22) > my0)
+                  && ((r->sy * 24 + 22) >= my0)
                 ) {
                     collisions += game_battle_missile_rock_collide(bt, m);
                 }
@@ -772,8 +772,8 @@ static void game_battle_item_move_find_route(struct battle_s *bt, uint8_t *route
         game_battle_set_route_from_tbl(route, tblx, tbly, len);
     } else {
         int minrlen = 999, minlen = 999;
-        for (int sy2 = 0; sy2 < BATTLE_AREA_H; ++sy2) {
-            for (int sx2 = 0; sx2 < BATTLE_AREA_W; ++sx2) {
+        for (int sx2 = 0; sx2 < BATTLE_AREA_W; ++sx2) {
+            for (int sy2 = 0; sy2 < BATTLE_AREA_H; ++sy2) {
                 if ((b->sx == sx2) && (b->sy == sy2)) {
                     continue;   /* WASBUG? MOO1 does not check, may use -1 as index below */
                 }
@@ -794,22 +794,25 @@ static void game_battle_item_move_find_route(struct battle_s *bt, uint8_t *route
                                 game_battle_extend_route_from_tbl(route, tblx2, tbly2, len2);
                             }
                         } else {
-                            for (int sy3 = 0; sy3 < BATTLE_AREA_H; ++sy3) {
-                                for (int sx3 = 0; sx3 < BATTLE_AREA_W; ++sx3) {
-                                    if ((sx3 != sx2) || (sy3 != sy2)) {
+                            for (int sx3 = 0; sx3 < BATTLE_AREA_W; ++sx3) {
+                                for (int sy3 = 0; sy3 < BATTLE_AREA_H; ++sy3) {
+                                    if ((sx3 == sx2) && (sy3 == sy2)) {
+                                        break;  /* BUG? not continue */
+                                    }
+                                    {
                                         int len2;
                                         len2 = util_math_line_plot(sx2, sy2, sx3, sy3, tblx2, tbly2);
                                         if ((game_battle_area_check_line_ok(bt, tblx2, tbly2, len2) == 1) && (b->man >= (len + len2))) {
-                                            int tblx3[BATTLE_ROUTE_LEN], tbly3[BATTLE_ROUTE_LEN], rlen2, rlen3;
+                                            int tblx3[BATTLE_ROUTE_LEN], tbly3[BATTLE_ROUTE_LEN], rlen3, rlen2;
                                             rlen2 = util_math_get_route_len(tblx[len - 1], tbly[len - 1], tblx2, tbly2, len2);
                                             if ((rlen2 + rlen1) < minrlen) {
                                                 int len3;
                                                 len3 = util_math_line_plot(sx3, sy3, sx, sy, tblx3, tbly3);
                                                 if ((game_battle_area_check_line_ok(bt, tblx3, tbly3, len3) == 1) && (b->man >= (len + len2 + len3))) {
                                                     rlen3 = util_math_get_route_len(tblx2[len2 - 1], tbly2[len2 - 1], tblx3, tbly3, len3);
-                                                    if (((len3 + len + len2) <= minlen) && (rlen2 + rlen1 + rlen3) < minrlen) {
+                                                    if (((len3 + len + len2) <= minlen) && (rlen3 + rlen1 + rlen2) < minrlen) {
                                                         minlen = len3 + len + len2;
-                                                        minrlen = rlen2 + rlen1 + rlen3;
+                                                        minrlen = rlen3 + rlen1 + rlen2;
                                                         game_battle_set_route_from_tbl(route, tblx, tbly, len);
                                                         game_battle_extend_route_from_tbl(route, tblx2, tbly2, len2);
                                                         game_battle_extend_route_from_tbl(route, tblx3, tbly3, len3);
@@ -826,7 +829,6 @@ static void game_battle_item_move_find_route(struct battle_s *bt, uint8_t *route
             }
         }
     }
-    /*return minlen; BUG set to void retval on len==1 case */
 }
 
 static uint32_t game_battle_pulsar_get_dmg(struct battle_s *bt, int target_i, int v)
@@ -1108,10 +1110,8 @@ static bool game_battle_special(struct battle_s *bt, int attacker_i, int target_
         if ((bd->side == SIDE_L) || (bt->s[SIDE_R].race != RACE_NUM/*monster*/)) {
             int v;
             v = bd->complevel - rnd_1_n(3, &bt->g->seed) - rnd_1_n(3, &bt->g->seed);
-            SETMAX(v, -128);
             bd->complevel = v;
             v = bd->misdefense - rnd_1_n(3, &bt->g->seed) - rnd_1_n(3, &bt->g->seed);
-            SETMAX(v, -128);
             SETMAX(v, bd->defense);
             bd->misdefense = v;
             if (!bt->autoresolve) {
@@ -1979,20 +1979,20 @@ void game_battle_area_setup(struct battle_s *bt)
                 dist = util_math_dist_maxabs(b->sx, b->sy, b2->sx, b2->sy);
                 if (i == 0) {
                     v = -30;
-                    for (int i = 0; i < num_weap; ++i) {
+                    for (int j = 0; j < num_weap; ++j) {
                         bool is_missile;
                         const struct shiptech_weap_s *w;
-                        w = &(tbl_shiptech_weap[b->wpn[i].t]);
+                        w = &(tbl_shiptech_weap[b->wpn[j].t]);
                         is_missile = ((w->damagemax == w->damagemin) && (!w->is_bomb) && (w->misstype == 0));
-                        if ((b->actman > 0) || ((w->range >= dist) && (b->wpn[i].numfire > 0) && (b->wpn[i].numshots != 0))) {
+                        if ((b->actman > 0) || ((w->range >= dist) && (b->wpn[j].numfire > 0) && (b->wpn[j].numshots != 0))) {
                             bt->turn_done = false;
                         }
-                        if ((b->wpn[i].numshots == -1) && (w->misstype == 0)) {
+                        if ((b->wpn[j].numshots == -1) && (w->misstype == 0)) {
                             range = w->range + b->extrarange;
                         } else {
                             range = w->range;
                         }
-                        if ((range >= dist) && ((b->missile == 1) || (!is_missile)) && (b->wpn[i].numfire > 0) && (b->wpn[i].numshots != 0)) {
+                        if ((range >= dist) && ((b->missile == 1) || (!is_missile)) && (b->wpn[j].numfire > 0) && (b->wpn[j].numshots != 0)) {
                             v = 30;
                         }
                     }
