@@ -604,6 +604,7 @@ int game_design_build_tbl_fit_engine(struct game_s *g, struct game_design_s *gd,
     shipdesign_t *sd = &(gd->sd);
     ship_engine_t actengine = sd->engine;
     int last = 0;
+    buf[0] = 1/*HAVE*/;
     for (int i = 0; i < SHIP_ENGINE_NUM; ++i) {
         if (game_tech_player_has_tech(g, TECH_FIELD_PROPULSION, tbl_shiptech_engine[i].tech_i, gd->player_i)) {
             sd->engine = i;
@@ -775,7 +776,7 @@ void game_design_scrap(struct game_s *g, player_id_t player, int shipi, bool fla
         bs = p->buildship;
         if ((p->owner == player) && (bs != BUILDSHIP_STARGATE)) {
             if (bs == shipi) {
-                if (IS_AI(g, player) || (!flag_for_new)) {
+                if (!IS_HUMAN(g, player) || (!flag_for_new)) {
                     p->buildship = 0;
                 } else {
                     p->buildship = e->shipdesigns_num - 1;
