@@ -224,7 +224,7 @@ void game_event_new(struct game_s *g)
         type = rnd_1_n(GAME_EVENT_NUM - 1, &g->seed);
         if (0
           || BOOLVEC_IS1(g->evn.done, type)
-          || ((type == GAME_EVENT_REBELLION) && (IS_AI(g, player) || (g->evn.home[player] == planet)))
+          || ((type == GAME_EVENT_REBELLION) && (!IS_HUMAN(g, player) || (g->evn.home[player] == planet)))
           || ((type == GAME_EVENT_QUAKE) && (p->pop < 50))
           || (((type == GAME_EVENT_CRYSTAL) || (type == GAME_EVENT_AMOEBA)) && (g->year < 200))
           || (((type == GAME_EVENT_CRYSTAL) || (type == GAME_EVENT_AMOEBA)) && (g->evn.crystal.exists || g->evn.amoeba.exists))
@@ -1145,7 +1145,7 @@ bool game_event_run(struct game_s *g, struct game_end_s *ge)
         g->guardian_killer = PLAYER_NONE;
     }
     /* MOO1 has the following way before the guardian news which gives a strange news order */
-    if (g->evn.have_orion_conquer && BOOLVEC_IS0(g->evn.done, 17)) { /* WASBUG MOO1 nevers sets have_orion_conquer */
+    if (g->evn.have_orion_conquer && BOOLVEC_IS0(g->evn.done, 17)) {
         player_id_t player = g->evn.have_orion_conquer - 1;
         empiretechorbit_t *e = &(g->eto[player]);
         BOOLVEC_SET1(g->evn.done, 17);
