@@ -30,7 +30,7 @@
 
 /* index to planets.lbx + 1 */
 /* index to starview.lbx - 6 */
-static const uint8_t tbl_planet_type_infogfx[PLANET_TYPE_NUM - 1][6] = {
+static const uint8_t tbl_planet_type_infogfx[PLANET_TYPE_NUM][6] = {
     { 0x01, 0x01, 0x01, 0x01, 0x01, 0x01 },
     { 0x05, 0x05, 0x14, 0x14, 0x22, 0x22 },
     { 0x04, 0x04, 0x06, 0x06, 0x17, 0x17 },
@@ -66,7 +66,6 @@ static void game_generate_planets(struct game_s *g)
 {
     /* assumes the planet data is already 0'd by caller */
     uint16_t tblpx[PLANETS_MAX], tblpy[PLANETS_MAX];
-    uint16_t i;
 
     for (uint16_t h = 0; h < g->galaxy_h; ++h) {
         for (uint16_t w = 0; w < g->galaxy_w; ++w) {
@@ -74,8 +73,7 @@ static void game_generate_planets(struct game_s *g)
             again:
             x = rnd_1_n(0x2b, &g->seed) + w * 0x1c + 9;
             y = rnd_1_n(0x33, &g->seed) + h * 0x20 + 7;
-            i = 0;
-            for (i = 0; i < (h * g->galaxy_w + w); ++i) {
+            for (uint16_t i = 0; i < (h * g->galaxy_w + w); ++i) {
                 if ((tblpx[i] < x) || (tblpy[i] < y)) {
                     if (util_math_dist_fast(tblpx[i], tblpy[i], x, y) < 20) {
                         goto again;
@@ -89,7 +87,7 @@ static void game_generate_planets(struct game_s *g)
         }
     }
 
-    for (i = 0; i < g->galaxy_stars; ++i) {
+    for (int i = 0; i < g->galaxy_stars; ++i) {
         bool in_nebula;
         planet_t *p;
 
@@ -188,7 +186,7 @@ static void game_generate_planets(struct game_s *g)
                     if ((r > 0xc) && (r < 0x10)) { t = PLANET_TYPE_ARID; }
                     if ((r > 0xf) && (r < 0x12)) { t = PLANET_TYPE_OCEAN; }
                     if ((r > 0x11) && (r < 0x14)) { t = PLANET_TYPE_JUNGLE; }
-                    if (r >= 0x14) { t = PLANET_TYPE_TERRAN; }
+                    if (r == 0x14) { t = PLANET_TYPE_TERRAN; }
                     break;
                 case STAR_TYPE_GREEN:
                     /*if (r < 2) { t = PLANET_TYPE_NOT_HABITABLE; }*/
@@ -391,7 +389,7 @@ static void game_generate_planets(struct game_s *g)
 
     {
         uint16_t tx = 0, ty = 0;
-        for (i = 0; i < g->galaxy_stars; ++i) {
+        for (int i = 0; i < g->galaxy_stars; ++i) {
             planet_t *p;
             p = &g->planet[i];
             if (p->x > tx) {
@@ -1114,10 +1112,10 @@ int game_new(struct game_s *g, struct game_aux_s *gaux, struct game_new_options_
         const uint8_t *rawdata;
         rawdata = gaux->research.d0;
         for (int f = 0; f < 6; ++f) {
-            researchflag[f * 50] = 0;
-            for (int t = 1; t < 50; ++t) {
+            for (int t = 0; t < 50; ++t) {
                 researchflag[f * 50 + t] = (rawdata[(f * 50 + t) * 6] != 0xff) ? 1 : 0;
             }
+            researchflag[f * 50] = 0;
         }
     }
     researchflag[TECH_FIELD_WEAPON * 50 + (TECH_WEAP_DEATH_RAY - 1)] = 0;
