@@ -156,6 +156,7 @@ static const struct numtbl_s {
     DEFNUMITEML(deterministic, NUMTYPE_BOOL, 0, 1),
     DEFNUMITEML(ai_trans_range_fix, NUMTYPE_BOOL, 0, 1),
     DEFNUMITEML(ai_4_colony_curse_fix, NUMTYPE_BOOL, 0, 1),
+    DEFNUMITEML(ai_first_tech_cost_fix, NUMTYPE_BOOL, 0, 1),
     DEFNUMITEML(bt_turn_max, NUMTYPE_S, 1, 0xffff),
     DEFNUMITEML(bt_wait_no_reload, NUMTYPE_BOOL, 0, 1),
     DEFNUMITEML(bt_precap_tohit, NUMTYPE_BOOL, 0, 1),
@@ -220,6 +221,9 @@ static const struct numtbl_s {
     DEFNUMITEMLTBLL(tbl_hull_w, NUMTYPE_U8, 0, 0xff),
     DEFNUMITEMLTBLL(tech_costmuld, NUMTYPE_U8, 0, 0xff),
     DEFNUMITEMLTBLL(tech_costmula, NUMTYPE_U8, 0, 0xff),
+    DEFNUMITEML(tech_costmuld2, NUMTYPE_S, 1, 0x7fffffff),
+    DEFNUMITEML(tech_costmula2, NUMTYPE_S, 1, 0x7fffffff),
+    DEFNUMITEML(tech_costmul, NUMTYPE_S, 1, 0x7fffffff),
     DEFNUMITEMLTBL(tcostm_human, game_num_tech_costmulr[RACE_HUMAN], NUMTYPE_U8, 0, 0xff),
     DEFNUMITEMLTBL(tcostm_mrrshan, game_num_tech_costmulr[RACE_MRRSHAN], NUMTYPE_U8, 0, 0xff),
     DEFNUMITEMLTBL(tcostm_silicoid, game_num_tech_costmulr[RACE_SILICOID], NUMTYPE_U8, 0, 0xff),
