@@ -671,11 +671,12 @@ const char *game_tech_get_newtech_msg(const struct game_s *g, player_id_t pi, st
     return buf;
 }
 
-int game_tech_current_research_percent1(const struct empiretechorbit_s *e, tech_field_t field)
+int game_tech_current_research_percent1(const struct game_s *g, player_id_t player, tech_field_t field)
 {
     uint32_t invest, cost;
     int slider, t1, t3, percent;
-    cost = e->tech.cost[field];
+    const empiretechorbit_t *e = &(g->eto[player]);
+    cost = game_tech_get_field_cost(g, player, field);
     slider = e->tech.slider[field];
     if ((cost == 0) || (slider == 0)) {
         return 0;
@@ -689,11 +690,12 @@ int game_tech_current_research_percent1(const struct empiretechorbit_s *e, tech_
     return percent;
 }
 
-int game_tech_current_research_percent2(const struct empiretechorbit_s *e, tech_field_t field)
+int game_tech_current_research_percent2(const struct game_s *g, player_id_t player, tech_field_t field)
 {
     uint32_t invest, cost;
     int slider, t1, t3;
-    cost = e->tech.cost[field];
+    const empiretechorbit_t *e = &(g->eto[player]);
+    cost = game_tech_get_field_cost(g, player, field);
     slider = e->tech.slider[field];
     if ((cost == 0) || (slider == 0)) {
         return 0;
@@ -712,11 +714,12 @@ int game_tech_current_research_percent2(const struct empiretechorbit_s *e, tech_
     }
 }
 
-bool game_tech_current_research_has_max_bonus(const struct empiretechorbit_s *e, tech_field_t field)
+bool game_tech_current_research_has_max_bonus(const struct game_s *g, player_id_t player, tech_field_t field)
 {
     uint32_t invest, cost;
     int slider, t1, t3;
-    cost = e->tech.cost[field];
+    const empiretechorbit_t *e = &(g->eto[player]);
+    cost = game_tech_get_field_cost(g, player, field);
     slider = e->tech.slider[field];
     if ((cost == 0) || (slider == 0)) {
         return false;
@@ -727,9 +730,10 @@ bool game_tech_current_research_has_max_bonus(const struct empiretechorbit_s *e,
     return (t1 <= (t3 * 2) && t3 > 0);
 }
 
-void game_tech_set_to_max_bonus(struct empiretechorbit_s *e, tech_field_t field)
+void game_tech_set_to_max_bonus(struct game_s *g, player_id_t player, tech_field_t field)
 {
-    bool has_bonus, had_bonus = game_tech_current_research_has_max_bonus(e, field);
+    bool has_bonus, had_bonus = game_tech_current_research_has_max_bonus(g, player, field);
+    empiretechorbit_t *e = &(g->eto[player]);
     techdata_t *t = &(e->tech);
     int16_t prev, v = t->slider[field];
     do {
@@ -738,7 +742,7 @@ void game_tech_set_to_max_bonus(struct empiretechorbit_s *e, tech_field_t field)
         SETRANGE(v, 0, 100);
         t->slider[field] = v;
         game_adjust_slider_group(t->slider, field, v, TECH_FIELD_NUM, t->slider_lock);
-        has_bonus = game_tech_current_research_has_max_bonus(e, field);
+        has_bonus = game_tech_current_research_has_max_bonus(g, player, field);
         v = t->slider[field];
     } while ((has_bonus == had_bonus) && (v != prev));
 }
@@ -876,6 +880,25 @@ int game_tech_get_field_percent(const struct game_s *g, player_id_t player, tech
     return v;
 }
 
+int game_tech_get_field_cost(const struct game_s *g, player_id_t player, tech_field_t field)
+{
+    const empiretechorbit_t *e = &(g->eto[player]);
+    uint32_t cost = e->tech.cost[field];
+    if (IS_HUMAN(g, player)) {
+        if (game_num_tech_costmuld2 != 100) {
+            cost = (cost * game_num_tech_costmuld2) / 100;
+        }
+    } else {
+        if (game_num_tech_costmula2 != 100) {
+            cost = (cost * game_num_tech_costmula2) / 100;
+        }
+    }
+    if (game_num_tech_costmul != 100) {
+        cost = (cost * game_num_tech_costmul) / 100;
+    }
+    return cost;
+}
+
 void game_tech_research(struct game_s *g)
 {
     for (player_id_t player = PLAYER_0; player < g->players; ++player) {
@@ -894,7 +917,7 @@ void game_tech_research(struct game_s *g)
             invest += t3 + t1;
             td->investment[field] = invest;
             td->percent[field] = game_tech_get_field_percent(g, player, field);
-            cost = td->cost[field];
+            cost = game_tech_get_field_cost(g, player, field);
             if ((cost != 0) && (slider != 0) && (total_research != 0)) {
                 if (cost < invest) {
                     int v;
