@@ -27,16 +27,17 @@ extern uint8_t game_tech_get_gfx_i(const struct game_aux_s *gaux, tech_field_t f
 extern const char *game_tech_get_name(const struct game_aux_s *gaux, tech_field_t field, int tech, char *buf, size_t bufsize);
 extern const char *game_tech_get_descr(const struct game_aux_s *gaux, tech_field_t field, int tech, char *buf, size_t bufsize);
 extern const char *game_tech_get_newtech_msg(const struct game_s *g, player_id_t pi, struct newtech_s *nt, char *buf, size_t bufsize);
-extern int game_tech_current_research_percent1(const struct empiretechorbit_s *e, tech_field_t field);
-extern int game_tech_current_research_percent2(const struct empiretechorbit_s *e, tech_field_t field);
-extern bool game_tech_current_research_has_max_bonus(const struct empiretechorbit_s *e, tech_field_t field);
-extern void game_tech_set_to_max_bonus(struct empiretechorbit_s *e, tech_field_t field);
+extern int game_tech_current_research_percent1(const struct game_s *g, player_id_t player, tech_field_t field);
+extern int game_tech_current_research_percent2(const struct game_s *g, player_id_t player, tech_field_t field);
+extern bool game_tech_current_research_has_max_bonus(const struct game_s *g, player_id_t player, tech_field_t field);
+extern void game_tech_set_to_max_bonus(struct game_s *g, player_id_t player, tech_field_t field);
 extern void game_tech_get_new(struct game_s *g, player_id_t player, tech_field_t field, uint8_t tech, techsource_t source, int a8, player_id_t stolen_from, bool flag_frame);
 extern void game_tech_finish_new(struct game_s *g, player_id_t player);
 extern bool game_tech_can_choose(const struct game_s *g, player_id_t player, tech_field_t field);
 extern uint32_t game_tech_get_next_rp(const struct game_s *g, player_id_t player, tech_field_t field, uint8_t tech);
 extern void game_tech_start_next(struct game_s *g, player_id_t player, tech_field_t field, uint8_t tech);
 extern int game_tech_get_field_percent(const struct game_s *g, player_id_t player, tech_field_t field);
+extern int game_tech_get_field_cost(const struct game_s *g, player_id_t player, tech_field_t field);
 extern void game_tech_research(struct game_s *g);
 extern void game_tech_get_orion_loot(struct game_s *g, player_id_t player);
 extern void game_tech_get_artifact_loot(struct game_s *g, uint8_t planet, player_id_t player);
