@@ -18,6 +18,7 @@ int mouse_stored_y = 0;
 int mouse_click_x = 0;
 int mouse_click_y = 0;
 int mouse_click_buttons = 0;
+int mouse_cursor_scale = 1;
 
 /* ------------------------------------------------------------------------- */
 
@@ -45,12 +46,6 @@ void mouse_set_scroll_from_hw(int scroll)
     mouse_scroll += scroll;
 }
 
-void mouse_set_xy(int mx, int my)
-{
-    moouse_x = mx;
-    moouse_y = my;
-}
-
 void mouse_set_click_xy(int mx, int my)
 {
     mouse_have_click_sw = true;
