@@ -43,11 +43,11 @@ void ui_extra_toggle_preset(bool enabled)
     game_opt_skip_intro_always = enabled;
     ui_space_combat_autoresolve = enabled;
     ui_sm_ships_enabled = enabled;
-    ui_sm_distance_tooltip = enabled;
     ui_sm_expanded_scroll = enabled;
     ui_sm_explicit_cursor_context = enabled;
     ui_sm_no_question_mark_cursor = enabled;
     ui_illogical_hotkey_fix = enabled;
+    ui_sm_smoother_scrolling = enabled;
     ui_kbd_cursor_keys_fix = enabled;
     ui_mouse_lmb_fix = enabled;
     ui_mouse_warp_disabled = enabled;
@@ -95,14 +95,15 @@ const struct cfg_items_s ui_cfg_items[] = {
     CFG_ITEM_BOOL("space_combat_autoresolve", &ui_space_combat_autoresolve),
     CFG_ITEM_BOOL("ui_sm_ships_enabled", &ui_sm_ships_enabled),
     CFG_ITEM_BOOL("sm_expanded_scroll", &ui_sm_expanded_scroll),
-    CFG_ITEM_BOOL("sm_distance_tooltip", &ui_sm_distance_tooltip),
     CFG_ITEM_BOOL("sm_no_question_mark_cursor", &ui_sm_no_question_mark_cursor),
     CFG_ITEM_BOOL("sm_explicit_cursor_context", &ui_sm_explicit_cursor_context),
     CFG_ITEM_BOOL("mouse_lmb_fix", &ui_mouse_lmb_fix),
     CFG_ITEM_BOOL("mouse_warp_disabled", &ui_mouse_warp_disabled),
     CFG_ITEM_BOOL("copy_protection_disabled", &ui_copyprotection_disabled),
     CFG_ITEM_BOOL("sm_mouseover_focus", &ui_sm_mouseover_focus),
+    CFG_ITEM_BOOL("sm_smoother_scrolling", &ui_sm_smoother_scrolling),
     CFG_ITEM_BOOL("sm_mouse_scroll", &ui_sm_mouse_scroll),
+    CFG_ITEM_BOOL("sm_uhjk_scroll", &ui_sm_uhjk_scroll),
     CFG_ITEM_BOOL("kbd_cursor_keys_fix", &ui_kbd_cursor_keys_fix),
     CFG_ITEM_COMMENT("0..146"),
     CFG_ITEM_INT("uiicon", &ui_icon, check_ui_icon),
@@ -182,14 +183,15 @@ bool ui_load_opts_extra = false;
 bool ui_space_combat_autoresolve = false;
 bool ui_sm_ships_enabled = false;
 bool ui_sm_expanded_scroll = false;
-bool ui_sm_distance_tooltip = false;
 bool ui_sm_no_question_mark_cursor = false;
 bool ui_sm_explicit_cursor_context = false;
 bool ui_mouse_lmb_fix = false;
 bool ui_mouse_warp_disabled = false;
 bool ui_copyprotection_disabled = false;
 bool ui_sm_mouseover_focus = false;
+bool ui_sm_smoother_scrolling = false;
 bool ui_sm_mouse_scroll = false;
+bool ui_sm_uhjk_scroll = false;
 bool ui_kbd_cursor_keys_fix = false;
 bool ui_mwi_slider = false;
 bool ui_mwi_counter = false;
@@ -449,7 +451,7 @@ void ui_early_show_message_box(const char *msg)
     }
     bool initialized = false;
     int64_t init_time = hw_get_time_us();
-    ui_palette_clear();
+    lbxpal_init();
     ui_palette_set_color(0, 0, 0, 0);
     ui_palette_set_color(1, 0x3f, 0x3f, 0x3f);
     hw_video_refresh_palette();
@@ -504,14 +506,10 @@ int ui_late_init(void)
       || init_lbx_ships()
       || set_ui_icon()
       || hw_video_init(UI_SCREEN_W, UI_SCREEN_H)
+      || lbxpal_init()
     ) {
         return 1;
     }
-    ui_palette_clear();
-    hw_video_refresh_palette();
-    if (lbxpal_init()) {
-        return 1;
-    }
     if (opt_audio_enabled) {
         const uint8_t sounds[] = { /* sounds used by ui or game code */
             0x24, 0x06, /* these are the most common sounds and are prepared first */
