@@ -160,7 +160,7 @@ ui_turn_action_t ui_game_turn(struct game_s *g, int *load_game_i_ptr, int pi)
                         ui_data.ui_main_loop_action_next = UI_MAIN_LOOP_SPECS;
                         ui_data.ui_main_loop_action_prev = UI_MAIN_LOOP_DESIGN;
                         ui_data.flag_scrap_for_new_design = true;
-                        scrapi = ui_specs(g, pi);
+                        scrapi = ui_specs(g, pi, false);
                         sd_num = g->eto[pi].shipdesigns_num;
                         ok = (sd_num < NUM_SHIPDESIGNS);
                         if (ok) {
@@ -175,7 +175,7 @@ ui_turn_action_t ui_game_turn(struct game_s *g, int *load_game_i_ptr, int pi)
                 ui_data.ui_main_loop_action = UI_MAIN_LOOP_STARMAP;
                 break;
             case UI_MAIN_LOOP_SPECS:
-                scrapi = ui_specs(g, pi);
+                scrapi = ui_specs(g, pi, false);
                 break;
             case UI_MAIN_LOOP_MUSTSCRAP:
                 if (scrapi >= 0) {
@@ -214,7 +214,7 @@ ui_turn_action_t ui_game_turn(struct game_s *g, int *load_game_i_ptr, int pi)
                 ui_data.ui_main_loop_action = UI_MAIN_LOOP_RACES;
                 break;
             case UI_MAIN_LOOP_EMPIREREPORT:
-                if ((opponi >= PLAYER_0) && (opponi < g->players) && (opponi != pi)) {
+                if (IS_PLAYER(g, opponi) && (opponi != pi)) {
                     ui_empirereport(g, pi, opponi);
                 } else {
                     LOG_DEBUG((3, "%s: invalid opponi %i for %i on EMPIREREPORT\n", __func__, opponi, pi));
@@ -222,7 +222,7 @@ ui_turn_action_t ui_game_turn(struct game_s *g, int *load_game_i_ptr, int pi)
                 ui_data.ui_main_loop_action = UI_MAIN_LOOP_RACES;
                 break;
             case UI_MAIN_LOOP_AUDIENCE:
-                if ((opponi >= PLAYER_0) && (opponi < g->players) && (opponi != pi)) {
+                if (IS_PLAYER(g, opponi) && (opponi != pi)) {
                     game_audience(g, pi, opponi);
                 } else {
                     LOG_DEBUG((3, "%s: invalid opponi %i for %i on AUDIENCE\n", __func__, opponi, pi));
@@ -248,7 +248,6 @@ ui_turn_action_t ui_game_turn(struct game_s *g, int *load_game_i_ptr, int pi)
             case UI_MAIN_LOOP_NEXT_TURN:
                 ui_data.ui_main_loop_action = UI_MAIN_LOOP_STARMAP;
                 ui_data.news.flag_also = false;
-                hw_video_copy_back_to_page2();  /* MOO1 does this early in game_turn_process */
                 return UI_TURN_ACT_NEXT_TURN;
             default:
                 LOG_DEBUG((0, "BUG: %s: invalid action 0x%x\n", __func__, ui_data.ui_main_loop_action));
@@ -280,6 +279,7 @@ void ui_game_start(struct game_s *g)
     */
     lbxpal_set_update_range(248, 255);
     ui_palette_set_n();
+    ui_draw_finish_mode = 1;
     ui_data.ui_main_loop_action = UI_MAIN_LOOP_STARMAP;
     for (int i = 0; i < g->players; ++i) {
         if (IS_HUMAN(g, i)) {
@@ -292,8 +292,6 @@ void ui_game_start(struct game_s *g)
         ui_data.star_frame[pli] = g->planet[pli].frame;
     }
     ui_data.seed = g->seed;
-    /* HACK ensure the game starts with a wipe, fixing -new help gfx glitch  */
-    ui_draw_finish_mode = 1;
 }
 
 void ui_game_end(struct game_s *g)
