@@ -42,7 +42,7 @@ static bool check_intro_files(void)
 
 void ui_play_intro(void)
 {
-    int16_t uiobji_now, uiobji_ma;
+    int16_t oi_skip;
     uint16_t frame = 0;
     bool flag_skip, flag_fadein = false;
     uint8_t *intro_sfx1;
@@ -88,9 +88,8 @@ void ui_play_intro(void)
     uiobj_table_clear();
     uiobj_set_skip_delay(true);
 
-    uiobji_ma = uiobj_add_mousearea_all(MOO_KEY_UNKNOWN);
+    oi_skip = uiobj_add_mousearea_all(MOO_KEY_UNKNOWN);
     flag_skip = 0;
-    uiobji_now = 0;
     uiobj_set_downcount(2);
 
     if (!flag_skip) {
@@ -100,9 +99,10 @@ void ui_play_intro(void)
     }
 
     while ((frame < 0x73) && (!flag_skip)) {
+        int16_t oi;
         ui_delay_prepare();
-        uiobji_now = uiobj_handle_input_cond();
-        if ((uiobji_now == uiobji_ma) || (uiobji_now == -1)) {
+        oi = uiobj_handle_input_cond();
+        if ((oi == oi_skip) || (oi == UIOBJI_ESC)) {
             flag_skip = true;
             break;
         } else {
@@ -136,9 +136,10 @@ void ui_play_intro(void)
     }
 
     while ((frame < 0x1e) && (!flag_skip)) {
+        int16_t oi;
         ui_delay_prepare();
-        uiobji_now = uiobj_handle_input_cond();
-        if ((uiobji_now == uiobji_ma) || (uiobji_now == -1)) {
+        oi = uiobj_handle_input_cond();
+        if ((oi == oi_skip) || (oi == UIOBJI_ESC)) {
             flag_skip = true;
             break;
         } else {
@@ -184,9 +185,10 @@ void ui_play_intro(void)
     }
 
     while ((frame < 0x46) && (!flag_skip)) {
+        int16_t oi;
         ui_delay_prepare();
-        uiobji_now = uiobj_handle_input_cond();
-        if ((uiobji_now == uiobji_ma) || (uiobji_now == -1)) {
+        oi = uiobj_handle_input_cond();
+        if ((oi == oi_skip) || (oi == UIOBJI_ESC)) {
             flag_skip = true;
             break;
         } else {
@@ -235,9 +237,10 @@ void ui_play_intro(void)
     }
 
     while ((frame < 0x45) && (!flag_skip)) {
+        int16_t oi;
         ui_delay_prepare();
-        uiobji_now = uiobj_handle_input_cond();
-        if ((uiobji_now == uiobji_ma) || (uiobji_now == -1)) {
+        oi = uiobj_handle_input_cond();
+        if ((oi == oi_skip) || (oi == UIOBJI_ESC)) {
             flag_skip = true;
             break;
         } else {
@@ -283,9 +286,10 @@ void ui_play_intro(void)
     }
 
     while ((frame < 0x28) && (!flag_skip)) {
+        int16_t oi;
         ui_delay_prepare();
-        uiobji_now = uiobj_handle_input_cond();
-        if ((uiobji_now == uiobji_ma) || (uiobji_now == -1)) {
+        oi = uiobj_handle_input_cond();
+        if ((oi == oi_skip) || (oi == UIOBJI_ESC)) {
             flag_skip = true;
             break;
         } else {
@@ -327,9 +331,10 @@ void ui_play_intro(void)
     }
 
     while ((frame < 0x1e) && (!flag_skip)) {
+        int16_t oi;
         ui_delay_prepare();
-        uiobji_now = uiobj_handle_input_cond();
-        if ((uiobji_now == uiobji_ma) || (uiobji_now == -1)) {
+        oi = uiobj_handle_input_cond();
+        if ((oi == oi_skip) || (oi == UIOBJI_ESC)) {
             flag_skip = true;
             break;
         } else {
@@ -366,9 +371,10 @@ void ui_play_intro(void)
     }
 
     while ((frame < 0xb4) && (!flag_skip)) {
+        int16_t oi;
         ui_delay_prepare();
-        uiobji_now = uiobj_handle_input_cond();
-        if ((uiobji_now == uiobji_ma) || (uiobji_now == -1)) {
+        oi = uiobj_handle_input_cond();
+        if ((oi == oi_skip) || (oi == UIOBJI_ESC)) {
             flag_skip = true;
             break;
         } else {
