@@ -142,10 +142,12 @@ typedef enum {
     MAIN_MENU_PAGE_OPTIONS_VIDEO,
     MAIN_MENU_PAGE_OPTIONS_ADDONS,
     MAIN_MENU_PAGE_OPTIONS_ADDONS_MESSAGE_FILTER,
-    MAIN_MENU_PAGE_OPTIONS_INTERFACE,
+    MAIN_MENU_PAGE_OPTIONS_MISC,
+    MAIN_MENU_PAGE_OPTIONS_STARMAP,
     MAIN_MENU_PAGE_OPTIONS_RULES,
     MAIN_MENU_PAGE_OPTIONS_RULES_AI,
     MAIN_MENU_PAGE_OPTIONS_RULES_BATTLE,
+    MAIN_MENU_PAGE_OPTIONS_RULES_DIFFICULTY,
     MAIN_MENU_PAGE_OPTIONS_RULES_FLEET_BEHAVIOR,
     MAIN_MENU_PAGE_OPTIONS_RULES_MONSTER,
     MAIN_MENU_PAGE_OPTIONS_RULES_ORBITAL_BOMBARDMENT,
@@ -312,26 +314,6 @@ static void mm_options_set_item_dimensions(struct main_menu_data_s *d, int i)
     }
 }
 
-static void mm_options_small_set_item_dimensions(struct main_menu_data_s *d, int i)
-{
-    struct main_menu_item_s *it = &d->items[i];
-    uint16_t step_y;
-    it->font_i = 2;
-    main_menu_set_item_wh(d, it);
-    if (d->item_count <= 8) {
-        step_y = 0x50 / d->item_count;
-        it->x = 0xa0;
-        it->y = 0x6f + step_y * i;
-    } else {
-        step_y = 0x50 / ((d->item_count + 1) / 2);
-        it->x = i%2 ? 0xe0 : 0x60;
-        if (i%2 == 0 && i == d->item_count - 1) {
-            it->x = 0xa0;
-        }
-        it->y = 0x6f + step_y * (i/2);
-    }
-}
-
 static void mm_custom_set_item_dimensions(struct main_menu_data_s *d, int i)
 {
     struct main_menu_item_s *it = &d->items[i];
@@ -366,6 +348,7 @@ static void main_menu_make_game_page(struct main_menu_data_s *d)
     menu_make_action(menu_allocate_item(), "Tutor", MAIN_MENU_ACT_TUTOR, MOO_KEY_t);
     menu_make_action_conditional(menu_allocate_item(), "Continue", MAIN_MENU_ACT_CONTINUE_GAME, main_menu_have_save_continue, MOO_KEY_c);
     menu_make_action_conditional(menu_allocate_item(), "Load Game", MAIN_MENU_ACT_LOAD_GAME, main_menu_have_save_any, MOO_KEY_l);
+    menu_make_action(menu_allocate_item(), "Load Game MOO", MAIN_MENU_ACT_LOAD_GAME_MOO13, MOO_KEY_m);
     menu_make_action(menu_allocate_item(), "New Game", MAIN_MENU_ACT_NEW_GAME, MOO_KEY_n);
     menu_make_page(menu_allocate_item(), "Custom Game", MAIN_MENU_PAGE_GAME_CUSTOM, MOO_KEY_u);
     menu_make_action(menu_allocate_item(), "Challenge", MAIN_MENU_ACT_CHALLENGE_GAME, MOO_KEY_h);
@@ -414,8 +397,9 @@ static void main_menu_make_options_page(struct main_menu_data_s *d)
     menu_make_page(menu_allocate_item(), "Input", MAIN_MENU_PAGE_OPTIONS_INPUT, MOO_KEY_i);
     menu_make_page(menu_allocate_item(), "Add-ons", MAIN_MENU_PAGE_OPTIONS_ADDONS, MOO_KEY_a);
     menu_make_page(menu_allocate_item(), "Sound", MAIN_MENU_PAGE_OPTIONS_SOUND, MOO_KEY_s);
-    menu_make_page(menu_allocate_item(), "Interface", MAIN_MENU_PAGE_OPTIONS_INTERFACE, MOO_KEY_n);
+    menu_make_page(menu_allocate_item(), "Starmap", MAIN_MENU_PAGE_OPTIONS_STARMAP, MOO_KEY_t);
     menu_make_page(menu_allocate_item(), "Video", MAIN_MENU_PAGE_OPTIONS_VIDEO, MOO_KEY_v);
+    menu_make_page(menu_allocate_item(), "Misc", MAIN_MENU_PAGE_OPTIONS_MISC, MOO_KEY_m);
     menu_make_page(menu_allocate_item(), "Preset", MAIN_MENU_PAGE_PRESET, MOO_KEY_p);
     menu_make_back(menu_allocate_item());
 }
@@ -423,14 +407,13 @@ static void main_menu_make_options_page(struct main_menu_data_s *d)
 static void main_menu_make_options_input_page(struct main_menu_data_s *d)
 {
     d->set_item_dimensions = mm_options_set_item_dimensions;
-    menu_make_bool(menu_allocate_item(), "Scroll by mouse", &ui_sm_mouse_scroll, MOO_KEY_s);
-    menu_make_int(menu_allocate_item(), "Scroll speed", &ui_sm_scroll_speed, 0, UI_SCROLL_SPEED_MAX, MOO_KEY_p);
     menu_make_bool(menu_allocate_item(), "Disable Mouse Warp", &ui_mouse_warp_disabled, MOO_KEY_w);
     menu_make_bool(menu_allocate_item(), "LMB Behavior Fix", &ui_mouse_lmb_fix, MOO_KEY_l);
     menu_make_bool(menu_allocate_item(), "Invert slider", &ui_mwi_slider, MOO_KEY_i);
     menu_make_bool(menu_allocate_item(), "Invert counter", &ui_mwi_counter, MOO_KEY_n);
     menu_make_bool_func(menu_allocate_item(), "Keyboard repeat", &ui_kbd_repeat, main_menu_toggle_kbd_repeat, MOO_KEY_k);
     menu_make_bool(menu_allocate_item(), "Direction Keys Fix", &ui_kbd_cursor_keys_fix, MOO_KEY_d);
+    menu_make_bool(menu_allocate_item(), "Illogical Hotkey Fix", &ui_illogical_hotkey_fix, MOO_KEY_h);
     menu_make_back(menu_allocate_item());
 }
 
@@ -459,7 +442,6 @@ static void main_menu_make_options_addons_page(struct main_menu_data_s *d)
     menu_make_bool(menu_allocate_item(), "UI Fixbugs", &ui_fixbugs_enabled, MOO_KEY_f);
     menu_make_bool(menu_allocate_item(), "Combat Autoresolve", &ui_space_combat_autoresolve, MOO_KEY_v);
     menu_make_bool(menu_allocate_item(), "UI SM Ships", &ui_sm_ships_enabled, MOO_KEY_s);
-    menu_make_bool(menu_allocate_item(), "SM Distance Tooltip", &ui_sm_distance_tooltip, MOO_KEY_t);
     menu_make_bool(menu_allocate_item(), "Load Options Extra", &ui_load_opts_extra, MOO_KEY_o);
     menu_make_page(menu_allocate_item(), "Message Filter", MAIN_MENU_PAGE_OPTIONS_ADDONS_MESSAGE_FILTER, MOO_KEY_m);
     menu_make_back(menu_allocate_item());
@@ -476,25 +458,35 @@ static void main_menu_make_options_addons_message_filter_page(struct main_menu_d
     menu_make_back(menu_allocate_item());
 }
 
-static void main_menu_make_options_interface_page(struct main_menu_data_s *d)
+static void main_menu_make_options_misc_page(struct main_menu_data_s *d)
 {
-    d->set_item_dimensions = mm_options_small_set_item_dimensions;
+    d->set_item_dimensions = mm_options_set_item_dimensions;
     menu_make_bool(menu_allocate_item(), "Skip Intro", &game_opt_skip_intro_always, MOO_KEY_i);
     menu_make_bool(menu_allocate_item(), "Skip Random News", &game_opt_skip_random_news, MOO_KEY_n);
-    menu_make_bool(menu_allocate_item(), "Explicit Cursor Context", &ui_sm_explicit_cursor_context, MOO_KEY_c);
-    menu_make_bool(menu_allocate_item(), "No '?' Starmap Cursor", &ui_sm_no_question_mark_cursor, MOO_KEY_q);
-    menu_make_bool(menu_allocate_item(), "Illogical Hotkey Fix", &ui_illogical_hotkey_fix, MOO_KEY_h);
-    menu_make_bool(menu_allocate_item(), "Expanded Starmap Scroll", &ui_sm_expanded_scroll, MOO_KEY_e);
-    menu_make_bool(menu_allocate_item(), "SM Mouseover Focus", &ui_sm_mouseover_focus, MOO_KEY_m);
     menu_make_bool(menu_allocate_item(), "Skip Copy Protection", &ui_copyprotection_disabled, MOO_KEY_p);
     menu_make_bool(menu_allocate_item(), "News Orion Colonized", &game_num_news_orion, MOO_KEY_o);
     menu_make_back(menu_allocate_item());
 }
 
+static void main_menu_make_options_starmap_page(struct main_menu_data_s *d)
+{
+    d->set_item_dimensions = mm_options_set_item_dimensions;
+    menu_make_bool(menu_allocate_item(), "Explicit Cursor Context", &ui_sm_explicit_cursor_context, MOO_KEY_c);
+    menu_make_bool(menu_allocate_item(), "No '?' Cursor", &ui_sm_no_question_mark_cursor, MOO_KEY_q);
+    menu_make_bool(menu_allocate_item(), "Expanded Scroll", &ui_sm_expanded_scroll, MOO_KEY_e);
+    menu_make_bool(menu_allocate_item(), "Mouseover Focus", &ui_sm_mouseover_focus, MOO_KEY_m);
+    menu_make_bool(menu_allocate_item(), "Scroll by mouse", &ui_sm_mouse_scroll, MOO_KEY_s);
+    menu_make_bool(menu_allocate_item(), "UHJK scroll", &ui_sm_uhjk_scroll, MOO_KEY_u);
+    menu_make_bool(menu_allocate_item(), "Smoother scrolling", &ui_sm_smoother_scrolling, MOO_KEY_o);
+    menu_make_int(menu_allocate_item(), "Scroll speed", &ui_sm_scroll_speed, 0, UI_SCROLL_SPEED_MAX, MOO_KEY_p);
+    menu_make_back(menu_allocate_item());
+}
+
 static void main_menu_make_options_rules_page(struct main_menu_data_s *d)
 {
     d->set_item_dimensions = mm_options_set_item_dimensions;
     menu_make_page(menu_allocate_item(), "AI Behavior", MAIN_MENU_PAGE_OPTIONS_RULES_AI, MOO_KEY_a);
+    menu_make_page(menu_allocate_item(), "Difficulty Modifiers", MAIN_MENU_PAGE_OPTIONS_RULES_DIFFICULTY, MOO_KEY_d);
     menu_make_page(menu_allocate_item(), "Fleet Behavior", MAIN_MENU_PAGE_OPTIONS_RULES_FLEET_BEHAVIOR, MOO_KEY_f);
     menu_make_page(menu_allocate_item(), "Monster", MAIN_MENU_PAGE_OPTIONS_RULES_MONSTER, MOO_KEY_m);
     menu_make_page(menu_allocate_item(), "Orbital Bombardment", MAIN_MENU_PAGE_OPTIONS_RULES_ORBITAL_BOMBARDMENT, MOO_KEY_o);
@@ -510,8 +502,8 @@ static void main_menu_make_options_rules_ai_page(struct main_menu_data_s *d)
     d->set_item_dimensions = mm_options_set_item_dimensions;
     menu_make_bool(menu_allocate_item(), "Transport Range Fix", &game_num_ai_trans_range_fix, MOO_KEY_UNKNOWN);
     menu_make_bool(menu_allocate_item(), "4th Colony Curse Fix", &game_num_ai_4_colony_curse_fix, MOO_KEY_UNKNOWN);
-    menu_make_bool(menu_allocate_item(), "Fleet Cheating Fix", &game_num_ai_fleet_cheating_fix, MOO_KEY_UNKNOWN);
     menu_make_bool(menu_allocate_item(), "Doom Stack Fix", &game_num_doom_stack_fix, MOO_KEY_UNKNOWN);
+    menu_make_bool(menu_allocate_item(), "First Tech Cost Fix", &game_num_ai_first_tech_cost_fix, MOO_KEY_UNKNOWN);
     menu_make_back(menu_allocate_item());
 }
 
@@ -525,6 +517,16 @@ static void main_menu_make_options_rules_battle_page(struct main_menu_data_s *d)
     menu_make_back(menu_allocate_item());
 }
 
+static void main_menu_make_options_rules_difficulty_page(struct main_menu_data_s *d)
+{
+    d->set_item_dimensions = mm_options_set_item_dimensions;
+    menu_make_bool(menu_allocate_item(), "AI Fleet Cheating Fix", &game_num_ai_fleet_cheating_fix, MOO_KEY_UNKNOWN);
+    menu_make_int(menu_allocate_item(), "Tech Cost Multiplier", &game_num_tech_costmul, 50, 400, MOO_KEY_UNKNOWN);
+    menu_make_int(menu_allocate_item(), "AI Tech Cost Multiplier", &game_num_tech_costmula2, 50, 100, MOO_KEY_UNKNOWN);
+    menu_make_int(menu_allocate_item(), "Human Tech Cost Multiplier", &game_num_tech_costmuld2, 100, 400, MOO_KEY_UNKNOWN);
+    menu_make_back(menu_allocate_item());
+}
+
 static void main_menu_make_options_rules_fleet_behavior_page(struct main_menu_data_s *d)
 {
     d->set_item_dimensions = mm_options_set_item_dimensions;
@@ -638,7 +640,10 @@ static struct main_menu_page_s mm_pages[MAIN_MENU_PAGE_NUM] = {
         main_menu_make_options_addons_message_filter_page,
     },
     {
-        main_menu_make_options_interface_page,
+        main_menu_make_options_misc_page,
+    },
+    {
+        main_menu_make_options_starmap_page,
     },
     {
         main_menu_make_options_rules_page,
@@ -649,6 +654,9 @@ static struct main_menu_page_s mm_pages[MAIN_MENU_PAGE_NUM] = {
     {
         main_menu_make_options_rules_battle_page,
     },
+    {
+        main_menu_make_options_rules_difficulty_page,
+    },
     {
         main_menu_make_options_rules_fleet_behavior_page,
     },
@@ -941,6 +949,17 @@ main_menu_action_t ui_main_menu(struct game_new_options_s *newopts, struct game_
                     ui_draw_finish_mode = 1;
                 }
                 break;
+            case MAIN_MENU_ACT_LOAD_GAME_MOO13:
+                {
+                    int i;
+                    i = ui_load_game_moo13();
+                    if (i >= 0) {
+                        *load_game_i_ptr = i;
+                        flag_done = true;
+                    }
+                    ui_draw_finish_mode = 1;
+                }
+                break;
             case MAIN_MENU_ACT_QUIT_GAME:
                 flag_done = true;
                 break;
