@@ -50,12 +50,14 @@ static uint8_t ui_starmap_cursor_on_star(const struct starmap_data_s *d, int16_t
 
 /* -------------------------------------------------------------------------- */
 
-static void ui_starmap_draw_planetinfo_do(const struct game_s *g, player_id_t api, uint8_t planet_i, bool explored, bool show_plus)
+static void ui_starmap_draw_planetinfo_do(const struct game_s *g, player_id_t api, uint8_t planet_i, bool explored, bool show_plus, bool draw_name)
 {
     const planet_t *p = &g->planet[planet_i];
     if (explored || (ui_extra_enabled && g->gaux->flag_cheat_stars)) {
-        lbxfont_select_set_12_4(4, 0xf, 0, 0);
-        lbxfont_print_str_center(269, 10, p->name, UI_SCREEN_W, ui_scale);
+        if (draw_name) {
+            lbxfont_select_set_12_4(4, 0xf, 0, 0);
+            lbxfont_print_str_center(269, 10, p->name, UI_SCREEN_W, ui_scale);
+        }
         /* stars in nebulas get a purple instead of a red frame */
         if (ui_extra_enabled && p->battlebg==0) {
             ui_draw_box1(228, 25, 309, 52, 0xd3, 0xd3, ui_scale);
@@ -337,7 +339,7 @@ void ui_starmap_draw_basic(struct starmap_data_s *d)
             lbxgfx_draw_frame(282, 164, ui_data.gfx.starmap.col_butt_trans, UI_SCREEN_W, ui_scale);
         }
     }
-    ui_starmap_draw_planetinfo(g, d->api, g->planet_focus_i[d->api]);
+    ui_starmap_draw_planetinfo(g, d->api, g->planet_focus_i[d->api], d->planet_draw_name);
     if (g->evn.build_finished_num[d->api]) {
         ui_starmap_draw_textbox_finished(g, d->api, g->planet_focus_i[d->api]);
     }
@@ -392,29 +394,24 @@ void ui_starmap_draw_starmap(struct starmap_data_s *d)
     lbxgfx_draw_frame(0, 0, ui_data.gfx.starmap.mainview, UI_SCREEN_W, ui_scale);
     uiobj_set_limits(STARMAP_LIMITS);
     {
+        uint8_t *gfx1, *gfx2;
         int x0, y0, x1, y1, lx, ly;
         x0 = (-x / 4) + 6;
         y0 = (-y / 4) + 6;
         x1 = ((-x + 1) / 2) + 6;
         y1 = ((-y + 1) / 2) + 6;
+        gfx1 = ui_fixbugs_enabled ? ui_data.gfx.starmap.starbak2 : ui_data.gfx.starmap.starback;
+        gfx2 = ui_fixbugs_enabled ? ui_data.gfx.starmap.starback : ui_data.gfx.starmap.starbak2;
         lx = 222 * ui_scale - 1;
         ly = 178 * ui_scale - 1;
         for (int yb = y0; yb < ly; yb += 200) {
             for (int xb = x0; xb < lx; xb += 320) {
-                if (ui_fixbugs_enabled) {
-                    lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starbak2, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
-                } else {
-                    lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starback, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
-                }
+                lbxgfx_draw_frame_offs(xb, yb, gfx1, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
             }
         }
         for (int yb = y1; yb < ly; yb += 200) {
             for (int xb = x1; xb < lx; xb += 320) {
-                if (ui_fixbugs_enabled) {
-                    lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starback, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
-                } else {
-                    lbxgfx_draw_frame_offs(xb, yb, ui_data.gfx.starmap.starbak2, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
-                }
+                lbxgfx_draw_frame_offs(xb, yb, gfx2, STARMAP_LIMITS, UI_SCREEN_W, starmap_scale);
             }
         }
     }
@@ -520,6 +517,13 @@ void ui_starmap_draw_starmap(struct starmap_data_s *d)
                 done = true;
             }
         }
+        if (ui_data.starmap.star_text_type == UI_SM_STAR_TEXT_DISTANCE) {
+            if (p->owner != d->api) {
+                lib_sprintf(str, sizeof(str), "%d parsecs", game_get_min_dist(g, d->api, pi));
+                lbxfont_print_str_center_limit(tx, ty, str, STARMAP_TEXT_LIMITS, UI_SCREEN_W, starmap_scale);
+                done = true;
+            }
+        }
         if (!done) {
             bool do_print = visible
                         || (pi == g->evn.planet_orion_i)
@@ -642,16 +646,6 @@ void ui_starmap_draw_starmap(struct starmap_data_s *d)
             }
         }
     }
-    if (ui_sm_distance_tooltip && ui_data.ui_main_loop_action == UI_MAIN_LOOP_STARMAP && d->dist_i != PLANET_NONE) {
-        int j = g->planet_focus_i[d->api];
-        const planet_t *p = &g->planet[d->dist_i], *q = &g->planet[j];
-        int px = 2 * (p->x - x) + 14, py = 2 * (p->y - y) + 14;
-        int qx = 2 * (q->x - x) + 14, qy = 2 * (q->y - y) + 14;
-        ui_draw_line_limit(px, py, qx, qy, 0x06, starmap_scale);
-        lbxfont_select(0, 0, 0, 0);
-        int l = g->gaux->star_dist[j][d->dist_i];
-        lbxfont_print_num_center_limit( (px + qx) / 2, (py + qy) / 2 - 2, l, STARMAP_TEXT_LIMITS, UI_SCREEN_W, starmap_scale);
-    }
 }
 
 void ui_starmap_draw_button_text(struct starmap_data_s *d, bool highlight)
@@ -799,14 +793,14 @@ void ui_starmap_handle_scrollkeys(struct starmap_data_s *d, int16_t oi)
     xh = ui_data.starmap.xhold;
     yh = ui_data.starmap.yhold;
     if (0
-      || kbd_is_pressed(MOO_KEY_u, 0, MOO_MOD_SHIFT | MOO_MOD_ALT | MOO_MOD_CTRL)
+      || (ui_sm_uhjk_scroll && kbd_is_pressed(MOO_KEY_u, 0, MOO_MOD_SHIFT | MOO_MOD_ALT | MOO_MOD_CTRL))
       || (ui_sm_mouse_scroll && (moouse_y <= 0))) {
         if (yh > 0) {
             yh = 0;
         }
         --yh;
     } else if (0
-      || kbd_is_pressed(MOO_KEY_j, 0, MOO_MOD_SHIFT | MOO_MOD_ALT | MOO_MOD_CTRL)
+      || (ui_sm_uhjk_scroll && kbd_is_pressed(MOO_KEY_j, 0, MOO_MOD_SHIFT | MOO_MOD_ALT | MOO_MOD_CTRL))
       || (ui_sm_mouse_scroll && (moouse_y >= UI_SCREEN_H - 1))) {
         if (yh < 0) {
             yh = 0;
@@ -819,14 +813,14 @@ void ui_starmap_handle_scrollkeys(struct starmap_data_s *d, int16_t oi)
         y += ui_starmap_scrollkey_accel(yh);
     }
     if (0
-      || kbd_is_pressed(MOO_KEY_h, 0, MOO_MOD_SHIFT | MOO_MOD_ALT | MOO_MOD_CTRL)
+      || (ui_sm_uhjk_scroll && kbd_is_pressed(MOO_KEY_h, 0, MOO_MOD_SHIFT | MOO_MOD_ALT | MOO_MOD_CTRL))
       || (ui_sm_mouse_scroll && (moouse_x <= 0))) {
         if (xh > 0) {
             xh = 0;
         }
         --xh;
     } else if (0
-      || kbd_is_pressed(MOO_KEY_k, 0, MOO_MOD_SHIFT | MOO_MOD_ALT | MOO_MOD_CTRL)
+      || (ui_sm_uhjk_scroll && kbd_is_pressed(MOO_KEY_k, 0, MOO_MOD_SHIFT | MOO_MOD_ALT | MOO_MOD_CTRL))
       || (ui_sm_mouse_scroll && (moouse_x >= UI_SCREEN_W - 1))) {
         if (xh < 0) {
             xh = 0;
@@ -1100,10 +1094,10 @@ void ui_starmap_update_reserve_fuel(struct game_s *g, struct shipnon0_s *sn0, co
     sn0->have_reserve_fuel = true;
 }
 
-void ui_starmap_draw_planetinfo(const struct game_s *g, player_id_t api, int planet_i)
+void ui_starmap_draw_planetinfo(const struct game_s *g, player_id_t api, int planet_i, bool draw_name)
 {
     const planet_t *p = &(g->planet[planet_i]);
-    ui_starmap_draw_planetinfo_do(g, api, planet_i, BOOLVEC_IS1(p->explored, api), true);
+    ui_starmap_draw_planetinfo_do(g, api, planet_i, BOOLVEC_IS1(p->explored, api), true, draw_name);
 }
 
 void ui_starmap_draw_planetinfo_2(const struct game_s *g, int p1, int p2, int planet_i)
@@ -1117,7 +1111,7 @@ void ui_starmap_draw_planetinfo_2(const struct game_s *g, int p1, int p2, int pl
     ) {
         explored = false;
     }
-    ui_starmap_draw_planetinfo_do(g, api, planet_i, explored, false);
+    ui_starmap_draw_planetinfo_do(g, api, planet_i, explored, false, true);
 }
 
 int ui_starmap_newship_next(const struct game_s *g, player_id_t pi, int i)
@@ -1177,7 +1171,7 @@ void ui_starmap_common_init(struct game_s *g, struct starmap_data_s *d, player_i
     d->controllable = false;
     d->show_planet_focus = true;
     d->anim_delay = 0;
-    d->dist_i = PLANET_NONE;
+    d->planet_draw_name = true;
     d->scrollx = 0;
     d->scrolly = 0;
     d->scrollz = starmap_scale;
