@@ -19,7 +19,7 @@ void ui_news_start(void)
 void ui_news(struct game_s *g, struct news_s *ns)
 {
     ui_switch_all(g);
-    game_news_get_msg(g, ns, ui_data.strbuf);
+    game_news_get_msg(g, ns, ui_data.strbuf, UI_STRBUF_SIZE);
     printf("GNN | %s", ui_data.strbuf);
     if (ns->type == GAME_NEWS_STATS) {
         for (int i = 0; i < ns->statsnum; ++i) {
