@@ -4,6 +4,7 @@
 #include "config.h"
 
 #include <stdio.h>
+#include <strings.h>
 
 #include "types.h"
 
@@ -11,11 +12,10 @@ extern char *util_concat(const char *s, ...);
 extern int util_concat_buf(char *buf, int buflen, ...);
 extern int util_get_line(char *buf, int bufsize, FILE *f);
 extern void util_fname_split(const char *path, char **directory_out, char **name_out);
-extern int util_get_fname_unused(char *buf, const char *fmt, int maxnum);
 extern int util_file_save(const char *name, const uint8_t *src, int size);
 extern uint8_t *util_file_load(const char *filename, uint32_t *len_out);
-extern void util_trim_whitespace(char *str);
-extern void util_str_tolower(char *str);
+extern void util_trim_whitespace(char *buf, size_t bufsize);
+extern void util_str_tolower(char *buf, size_t bufsize);
 extern bool util_parse_number(const char *str, uint32_t *val_ptr);
 extern bool util_parse_signed_number(const char *str, int *val_ptr);
 extern int32_t *util_parse_numbers(const char *str, char sep, int *numptr);
